Documentation
¶
Index ¶
Constants ¶
const MaxUnreadAllowed = 1e3
MaxUnreadAllowed Maximum number of unread messages allowed in orchestrator's incoming message buffer before pausing relaying
Variables ¶
var ErrNotPlayer = xerrors.New("not player")
var ErrWrongAddressType = xerrors.New("wrong address type")
Functions ¶
func NewController ¶
func NewController() node.Initializer
NewController creates a CLI app to start a Minows instance.
func NewMinows ¶
NewMinows creates a new Minows instance that starts listening. listen: listening address in multiaddress format, e.g. /ip4/127.0.0.1/tcp/80/ws public: public dial-able address in multiaddress format, e.g. /dns4/p2p-1.c4dt.dela.org/tcp/443/wss `public` can be nil and will be determined by the listening address and the port the host has bound to. key: private key representing this mino instance's identity
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.